@@ -38,6 +38,7 @@ module Text.Parser.Combinators
   , optional -- from Control.Applicative, parsec optionMaybe
   , skipOptional -- parsec optional
   , between
+  , surroundedBy
   , some     -- from Control.Applicative, parsec many1
   , many     -- from Control.Applicative
   , sepBy
@@ -84,6 +85,11 @@ import qualified Data.Attoparsec.Types as Att
 import qualified Data.Attoparsec.Combinator as Att
 import qualified Text.ParserCombinators.ReadP as ReadP
 
+#ifdef MIN_VERSION_binary
+import Control.Monad (when, unless)
+import qualified Data.Binary.Get as B
+#endif
+
 -- | @choice ps@ tries to apply the parsers in the list @ps@ in order,
 -- until one of them succeeds. Returns the value of the succeeding
 -- parser.
@@ -115,6 +121,12 @@ between :: Applicative m => m bra -> m ket -> m a -> m a
 between bra ket p = bra *> p <* ket
 {-# INLINE between #-}
 
+-- | @p \`surroundedBy\` f@ is @p@ surrounded by @f@. Shortcut for @between f f p@.
+-- As in @between@, returns the value returned by @p@.
+surroundedBy :: Applicative m => m a -> m sur -> m a
+surroundedBy p bound = between bound bound p
+{-# INLINE surroundedBy #-}
+
 -- | @sepBy p sep@ parses /zero/ or more occurrences of @p@, separated
 -- by @sep@. Returns a list of values returned by @p@.
 --
@@ -425,6 +437,18 @@ instance Att.Chunk t => Parsing (Att.Parser t) where
   eof             = Att.endOfInput
   notFollowedBy p = optional p >>= maybe (pure ()) (unexpected . show)
 
+#ifdef MIN_VERSION_binary
+instance Parsing B.Get where
+  try             = id
+  (<?>)           = flip B.label
+  skipMany p      = do skipped <- True <$ p <|> pure False
+                       when skipped $ skipMany p
+  unexpected      = fail
+  eof             = do isEof <- B.isEmpty
+                       unless isEof $ fail "Parsing.eof"
+  notFollowedBy p = optional p >>= maybe (pure ()) (unexpected . show)
+#endif
+
 instance Parsing ReadP.ReadP where
   try        = id
   (<?>)      = const
