@@ -45,6 +45,10 @@ import qualified Text.ParserCombinators.ReadP as ReadP
 import qualified Text.Parsec as Parsec
 import Text.Parser.Combinators
 
+#ifdef MIN_VERSION_binary
+import qualified Data.Binary.Get as B
+#endif
+
 -- | Additional functionality needed to describe parsers independent of input type.
 class Parsing m => LookAheadParsing m where
   -- | @lookAhead p@ parses @p@ without consuming any input.
@@ -88,6 +92,11 @@ instance (Parsec.Stream s m t, Show t) => LookAheadParsing (Parsec.ParsecT s u m
 instance Att.Chunk i => LookAheadParsing (Att.Parser i) where
   lookAhead = Att.lookAhead
 
+#ifdef MIN_VERSION_binary
+instance LookAheadParsing B.Get where
+  lookAhead = B.lookAhead
+#endif
+
 instance LookAheadParsing ReadP.ReadP where
   lookAhead p = ReadP.look >>= \s ->
                 ReadP.choice $ map (return . fst) $ ReadP.readP_to_S p s
